@@ -25,7 +25,7 @@ use Carp;
 require Exporter;
 @ISA = qw(Exporter);
 @EXPORT = qw(create_ikc_client);
-$VERSION = '0.10';
+$VERSION = '0.12';
 
 sub DEBUG { 0 }
 
@@ -165,7 +165,9 @@ sub ping
 sub disconnect
 {
     my($self)=@_;
-    $self->call('IKC/unregister', $self->{name}) if $self->{remote};
+    # 2001/01 why did we try to unregister ourselves?  unregister wouldn't
+    # be safe for remote kernels anyway
+    # $self->call('IKC/unregister', $self->{name}) if $self->{remote};
     delete @{$self->{remote}}{qw(socket connected name aliases)};
     $self->{remote}={};
 }
