@@ -25,7 +25,7 @@ use POE::Component::IKC::Specifier;
 require Exporter;
 @ISA = qw(Exporter);
 @EXPORT = qw(create_ikc_responder $ikc);
-$VERSION = '0.10';
+$VERSION = '0.12';
 
 sub DEBUG { 0 }
 
@@ -254,6 +254,7 @@ sub new
             'local'=>{IKC=>{remote_error=>1, # these states are auto-published
                             do_you_have=>1,
                             ping=>1,
+#                            unregister=>1,
                            },
                      },
             remote=>{},
@@ -309,7 +310,6 @@ sub request
                 $to->{state}, "'\n";
         }
 
-
         my $session=$kernel->alias_resolve($to->{session});
         die "Unknown session '$to->{session}'\n" unless $session;
 
@@ -325,6 +325,9 @@ sub request
     {
         chomp($@);
         my $err=$@.' ['.specifier_name($to).']';
+        $err.=' sent by ['.specifier_name($request->{from}).']'
+                                                    if $request->{from};
+        warn $err;
         DEBUG && warn "$$: Error in request: $err\n";
         unless($request->{is_error})    # don't send an error message back
         {                               # if this was an error itself
